% execute_ica() - graphic user interface (GUI) to laonch ICA
%                 process for fMRI data, all parameters can be
%                 assigned in a popup window.
% 
% Usage:
%   >> execute_ica;
%
% Inputs:
%
% Outputs:
%
% Author: Jeng-Ren Duann, CN:/Salk Inst. & SCCN/INC/UCSD, 2002-10
%
% See also: set_fmri_global_ui()

% --
% Copyright (C) 2002 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software

% $Log: execute_ica.m,v $
% Revision 1.6  2007/05/10  15:15:55  duann
%   Add option 'lrate' to ica decomposition
%
% Revision 1.5  2007/02/01  16:02:00  duann
%   Restore the FMRI.data base everytime restart the decomposition
%
% Revision 1.4  2007/01/30  10.10:00  duann
%   Add option of 'multi-run means'
%   If multi-run means detected, make voxmm multiple
%   Introduce a new FMRI field, runidx, to indicate if there are muliple runs
%   runidx only gives the starting scan no of each run
%
% Revision 1.3  2006/12/29 10:53:49  duann
%   Add option of 'remove voxel means'
%   Add field, 'voxmm' to FMRI data structure
%     (voxmm = mean(FMRI.data) or 0)
%   rm_voxmm = 'yes' (default for rm_voxmm is yes)
%   Change default ica_method to 'runica'
%
% Revision 1.2  2003/03/03 21:23:17  duann
% correct typo
%
% Revision 1.1  2003/02/06 18:57:44  duann
% Initial revision
%
 


function execute_ica

global FMRI;

if length(FMRI) == 0,
    fmrlab_messagedlg('Execute ICA',...
        'Error:',...
        ['No current data set exists. Please load a ''.fmr''' ...
            ' data files first']);
    return;
end
  
temp = findstr(FMRI.processed,'brain_extracted');
if isempty(temp),
    fmrlab_messagedlg('Execute ICA',...
        'Error:',...
        'Please remove off-brain voxels frist, run ''Process >> Extract Brain Voxels.''');
    return;
end
  
%FMRI.maxsteps = 512;
prompt = {'ICA routine used (binica, runica, runica2):',...
	  'Number of principal dimensions to retain (0 ->all):',...
	  'Annealing Angle (in degrees):',...
	  'Use Extended ICA (yes/no):',...
	  'Maximum training steps:',...
          'Remove voxel means (yes/no):',...
          'Multi-run means (starting scan no, 1, M, N, ...):',...
          'Learning ratio (0.00005):',...
	  'Block size:'};
ica_met = 'binica'; %default ica routine
if ~isempty(FMRI.pcano),
  str_pcano = num2str(FMRI.pcano);
else
  str_pcano = int2str(round(sqrt(size(FMRI.data,2)))); 
end

if ~isempty(FMRI.annealdeg),
  str_annealdeg = num2str(FMRI.annealdeg);
else
  str_annealdeg = '60';
end

if ~isempty(FMRI.extended),
  if FMRI.extended == 0,
    str_extended = 'no';
  else
    str_extended = 'yes';
  end
else
  str_extended = 'no';
end

if ~isempty(FMRI.maxsteps),
  str_maxsteps = num2str(FMRI.maxsteps);
else
  str_maxsteps = '512';
end

if ~isfield(FMRI,'voxmm'),
  FMRI.voxmm = 0;
end
rm_voxmm = 'yes';

% restore baseline of FMRI.data
if length(FMRI.voxmm) > 1,
  temp = zeros(size(FMRI.data));
  temp1 = [FMRI.runidx size(FMRI.data,1)+1];
  for ii=1:length(FMRI.runidx),
    temp(temp1(ii):temp1(ii+1)-1,:) = repmat(FMRI.voxmm(ii,:),temp1(ii+1)-temp1(ii),1);
  end
  FMRI.data = FMRI.data + temp;
  FMRI.voxmm = 0;
end

defs = {ica_met,str_pcano,str_annealdeg,str_extended,str_maxsteps,rm_voxmm,'','0.00005','0'};
a = fmrlab_inputdlg(prompt,'ICA Decomposition Parameters',1,defs);
if isempty(a),
  %errordlg('Cancelled by user ...!');
  return;
else
  ica_met = char(a(1));
  FMRI.pcano = str2num(char(a(2)));
  FMRI.annealdeg = str2num(char(a(3)));
  if strcmp(char(a(4)),'yes')
    FMRI.extended = 1;
  else
    FMRI.extended = 0;
  end
  FMRI.maxsteps = str2num(char(a(5)));
  if strcmp(char(a(6)),'yes')
    temp = str2num(char(a(7)));
    if isempty(temp),
      FMRI.runidx = 1; % single fMRI run
      FMRI.voxmm = mean(FMRI.data);
      temp = repmat(FMRI.voxmm,size(FMRI.data,1),1);
      FMRI.data = FMRI.data-temp;
    else
      FMRI.runidx = temp; % multiple fMRI runs
      temp = [FMRI.runidx size(FMRI.data,1)+1];
      FMRI.voxmm = zeros(length(FMRI.runidx),size(FMRI.data,2));
      for ii=1:length(FMRI.runidx)
        temp1 = mean(FMRI.data(temp(ii):temp(ii+1)-1,:));
        FMRI.voxmm(ii,:) = temp1;
        temp2 = repmat(temp1,temp(ii+1)-temp(ii),1);
        FMRI.data(temp(ii):temp(ii+1)-1,:) = FMRI.data(temp(ii):temp(ii+1)-1,:)-temp2;
      end
    end
  end
  FMRI.icalrate = str2num(char(a(8)));
  block_size = str2num(char(a(9)));
end

show_parameters;

arg = ['[w,sph]=' ica_met '(FMRI.data' ',' '''maxsteps''' ',' int2str(FMRI.maxsteps)];
if FMRI.pcano ~= 0,
  arg = [arg ',' '''' 'pca' '''' ',' int2str(FMRI.pcano)];
end

if FMRI.annealdeg ~= 60,
  arg = [arg ',' '''' 'annealdeg' '''' ',' int2str(FMRI.annealdeg)];
end

if FMRI.extended == 1,
  arg = [arg ',' '''' 'extended' '''' ',1'];
end

if block_size ~= 0,
  arg = [arg ',' '''blocksize''' ',' int2str(block_size)];
end

if FMRI.icalrate ~= 0.00005,
  arg = [arg ',' '''lrate''', ',' num2str(FMRI.icalrate)];
end

%if FMRI.maxsteps ~= 512,
%  arg = [arg ',' '''maxsteps''' ',' int2str(FMRI.maxsteps)];
%end

arg = [arg ');']
eval(arg);


  FMRI.icaweight = w;
  FMRI.icasphere = sph;
  FMRI.processed = [FMRI.processed ':ica_trained'];

  FMRI.comp_order = 0;
  %resort_comp;

show_parameters;

delete binica*
delete bias*