% fmrlab_batch_mutual_info() - calculate mutual information between the spatial maps
%                              of any pairs of independent components after ICA
%                              decomposition.
%
% Input:
%    z_thre - threshold in z value to create the ROA maps
%
% Output:
%    mu - upper tri of the mutual information matrix

function mu = fmrlab_batch_mutual_info(z_thre)

global FMRI

if nargin < 1,
  z_thre = 1.5; % default = 1.5
end

% check if the data containing ICA weights
a = findstr(FMRI.processed,' ');
temp_str = FMRI.processed(a(length(a))+1:length(FMRI.processed));
if strcmp(temp_str,'ica_trained') ~= 1,
  fmrlab_messagedlg('fmrlab_batch_pvaf()',...
                    'Error',...
                    'Please run ICA first to get ICA weights ...');
  return;
end

% calculate the component weights and source 
W = FMRI.icaweight * FMRI.icasphere;
u = W * FMRI.data;
invW = pinv(W);

mu = zeros(size(u,1),size(u,1));
fp = fopen('mutuinfo.txt','w');
for i=1:size(u,1),
  for j=i+1:size(u,1),
    % make up the component maps
    map1 = u(i,:);
    %map1 = (map1-mean(map1))/std(map1);
    %ii = find(abs(map1) < z_thre);
    %map1(ii) = 0;
    map2 = u(j,:);
    %map2 = (map2-mean(map2))/std(map2);
    %ii = find(abs(map2) < z_thre);
    %map2(ii) = 0;
    mu(i,j) = mutual_information(map1,map2);
    fprintf(fp,'%03d\t%03d\t%8.6f\n',i,j,mu(i,j));
  end
end
fclose(fp);
figure
imagesc(mu);