% fmrlab_batch_pvaf() - Create pvaf measures for every component in an ICA
%                       result. Save pvaf list in a text file for further
%                       usage.
%
% Input:
%     z_thre z value threshold to create ROA maps

function fmrlab_batch_pvaf(z_thre)

global FMRI

if nargin < 1,
  z_thre = 1.5; % default = 1.5
end

% check if the data containing ICA weights
a = findstr(FMRI.processed,' ');
temp_str = FMRI.processed(a(length(a))+1:length(FMRI.processed));
if strcmp(temp_str,'ica_trained') ~= 1,
  fmrlab_messagedlg('fmrlab_batch_pvaf()',...
                    'Error',...
                    'Please run ICA first to get ICA weights ...');
  return;
end

% calculate the component weights and source 
W = FMRI.icaweight * FMRI.icasphere;
u = W * FMRI.data;
invW = pinv(W);

fp = fopen('pvaf.txt','w');
for i=1:size(u,1), % component no.
  % make ROA
  temp = u(i,:);
  temp = (temp-mean(temp))/std(temp); % convert to z values
  ii = find(temp >= z_thre);

  raw_tc = mean(FMRI.data(:,ii)');
  mean_raw_tc = mean(raw_tc);
  data2 = invW(:,i)*u(i,:);
  bp_comp_tc = mean(data2(:,ii)');
  raw_tc = (raw_tc-mean_raw_tc)/mean_raw_tc;
  bp_comp_tc = (bp_comp_tc-mean(bp_comp_tc))/mean_raw_tc;
  vv = 100*(1-var(raw_tc-bp_comp_tc)/var(raw_tc));
  fprintf(fp,'%03d\t%8.4f\n',i,vv);
end
fclose(fp);