% fmrlab_eventedit() - 
%

function fmrlab_eventedit(act)
  
  global FMRI
  global FS
  global sf
  global tw
  global axg

  if length(FMRI) == 0,
    fmrlab_messagedlg('fmrlab_eventedit()',...
		      'Error:',...
		      ['No FMRI data available, please load FMRI' ...
		       ' dataset first']);
    return;
  end
  
  fmrlab_chkdataset;

  % check if no event table available
  if length(FMRI.event) == 0,
    fmrlab_messagedlg('fmrlab_eventedit()',...
		      'Error:',...
		      ['No event tables available, please generate' ...
		       ' first by: ''Event >> Generate Event Table''']);
    return;
  end
  
  if nargin < 1,
    act = 'init';
  end
  
  RGB_mainwin = [1 .984 .895];
  RGB_background = [0.860 0.824 0.618];
  RGB_button = [0.860 0.824 0.618]; 
  RGB_text = [0.333 0.283 0.003];
  
  pos_w = 700*sf(1); % window width
  pos_h = 400*sf(2); % window height
  list_h = 250*sf(2);
  axg = 5*min(sf);   % gap in x- and y-direction
  bw = 70*sf(1);    % width of button
  bh = 20*sf(2);     % height of button
  tw = 18;           % width of title bar

  switch(act),
   case 'init',
    f0 = findobj('name','Event Editor');
    if ~isempty(f0),
      figure(f0);
    else
      disp('Create Event Editor window...');
      S = get(0,'screensize');
      pos = [0 S(4)-tw-pos_h pos_w pos_h];
      f0 = figure( ...
            'name', 'Event Editor', ...
            'numbertitle','off',...
            'doublebuffer', 'on', ...
            'color',RGB_mainwin,...
            'menubar','none',...
            'position',pos,...
            'backingstore','off',...
            'deletefcn','fmrlab_eventedit(''close'');');
      % find names of all fields to make captions
      allfields = fieldnames(FMRI.event{1});
      % create listboxes according to the number of event fields
      list_w = floor((pos_w-2*axg-15)/length(allfields));
      ev_ax = [];
      ck_ax = [];
      cv_ax = [];
      ca_ax = [];
      for i=1:length(allfields),
	pos = [axg+(i-1)*list_w pos_h-list_h-bh-axg list_w list_h];
	f1 = uicontrol(...
	    'parent',f0,...
	    'style','listbox',...
	    'position',pos,...
	    'backgroundcolor',RGB_mainwin,...
	    'foregroundcolor',RGB_text,...
	    'callback','fmrlab_eventedit(''val_changed'');');
	ev_ax = [ev_ax f1];
	pos(2) = pos_h-bh-axg;
	pos(4) = bh;
	f1 = uicontrol(...
	    'parent',f0,...
	    'style','text',...
	    'position',pos,...
	    'backgroundcolor',RGB_mainwin,...
	    'foregroundcolor',RGB_text,...
	    'string',allfields(i),...
	    'fontsize',FS,...
	    'fontweight','bold');
	pos(2) = pos_h-list_h-2*bh-2*axg;
	f1 = uicontrol(...
	    'parent',f0,...
	    'style','checkbox',...
	    'position',pos,...
	    'backgroundcolor',RGB_mainwin,...
	    'foregroundcolor',RGB_text,...
	    'string','Expo?',...
	    'fontsize',FS);
	ck_ax = [ck_ax f1];
	pos(2) = pos_h-list_h-3*bh-3*axg;
	f1 = uicontrol(...
	    'parent',f0,...
	    'style','checkbox',...
	    'position',pos,...
	    'backgroundcolor',RGB_mainwin,...
	    'foregroundcolor',RGB_text,...
	    'string','Conv?',...
	    'fontsize',FS);
	cv_ax = [cv_ax f1];
	pos(2) = pos_h-list_h-4*bh-4*axg;
	f1 = uicontrol(...
	    'parent',f0,...
	    'style','edit',...
	    'position',pos,...
	    'backgroundcolor',RGB_mainwin,...
	    'foregroundcolor',RGB_text,...
	    'string','',...
	    'fontsize',FS);
	ca_ax = [ca_ax f1];
      end
      % fill up all field vals
      for j=1:length(allfields),
	temp = cell(1,length(FMRI.event));
	for i=1:length(FMRI.event),
	  temp{i} = getfield(FMRI.event{i},allfields{j});
	end
	set(ev_ax(j),'string',temp);
      end
      
      pos = [axg axg bw bh];
      f1 = uicontrol(...
	  'parent',f0,...
	  'style','pushbutton',...
	  'position',pos,...
	  'fontsize',FS,...
	  'backgroundcolor',RGB_button,...
	  'foregroundcolor',RGB_text,...
	  'string','Mark',...
	  'callback','fmrlab_eventedit(''mark_event'');');
      pos = [2*axg+bw axg bw bh];
      f1 = uicontrol(...
	  'parent',f0,...
	  'style','popupmenu',...
	  'position',pos,...
	  'fontsize',FS,...
	  'backgroundcolor',RGB_button,...
	  'foregroundcolor',RGB_text,...
	  'string','0',...
	  'tag','event_list',...
	  'callback','fmrlab_eventedit(''goto_event'');');
      if length(FMRI.eventlist) ~= 0,
	a = FMRI.eventlist(:);
	set(f1,'string',num2str(a));
      end
      pos = [3*axg+2*bw axg bw bh];
      f1 = uicontrol(...
	  'parent',f0,...
	  'style','pushbutton',...
	  'position',pos,...
	  'fontsize',FS,...
	  'backgroundcolor',RGB_button,...
	  'foregroundcolor',RGB_text,...
	  'string','UnMark',...
	  'callback','fmrlab_eventedit(''unmark_event'');');
      pos = [4*axg+3*bw axg bw bh];
      f1 = uicontrol(...
	  'parent',f0,...
	  'style','pushbutton',...
	  'position',pos,...
	  'fontsize',FS,...
	  'backgroundcolor',RGB_button,...
	  'foregroundcolor',RGB_text,...
	  'string','Unmark All',...
	  'callback','fmrlab_eventedit(''unmark_all'');');
      pos = [5*axg+4*bw axg bw bh];
      f1 = uicontrol(...
	  'parent',f0,...
	  'style','pushbutton',...
	  'position',pos,...
	  'fontsize',FS,...
	  'backgroundcolor',RGB_button,...
	  'foregroundcolor',RGB_text,...
	  'string','Export',...
	  'callback','fmrlab_eventedit(''export_event'');');
      pos = [6*axg+5*bw axg bw bh];
      f1 = uicontrol(...
	  'parent',f0,...
	  'style','pushbutton',...
	  'position',pos,...
	  'fontsize',FS,...
	  'backgroundcolor',RGB_button,...
	  'foregroundcolor',RGB_text,...
	  'string','Insert');
      pos = [7*axg+6*bw axg bw bh];
      f1 = uicontrol(...
	  'parent',f0,...
	  'style','pushbutton',...
	  'position',pos,...
	  'fontsize',FS,...
	  'backgroundcolor',RGB_button,...
	  'foregroundcolor',RGB_text,...
	  'string','Modify');
      pos = [8*axg+7*bw axg bw bh];
      f1 = uicontrol(...
	  'parent',f0,...
	  'style','pushbutton',...
	  'position',pos,...
	  'fontsize',FS,...
	  'backgroundcolor',RGB_button,...
	  'foregroundcolor',RGB_text,...
	  'string','Delete');
      pos = [9*axg+8*bw axg bw bh];
      f1 = uicontrol(...
	  'parent',f0,...
	  'style','pushbutton',...
	  'position',pos,...
	  'fontsize',FS,...
	  'backgroundcolor',RGB_button,...
	  'foregroundcolor',RGB_text,...
	  'string','Close',...
	  'callback','fmrlab_eventedit(''close'');');
      
      % save controls of list box in userdata
      userdata.ev_ax = ev_ax;
      userdata.ck_ax = ck_ax;
      userdata.cv_ax = cv_ax;
      userdata.ca_ax = ca_ax;
      set(gcf,'userdata',userdata);
    end
    
   case 'val_changed',
    val = get(gco,'value');
    top = get(gco,'listboxtop');
    userdata = get(gcf,'userdata');
    for i=1:length(userdata.ev_ax),
      set(userdata.ev_ax(i),...
	  'value',val);
    end
    for i=1:length(userdata.ev_ax),
      set(userdata.ev_ax(i),...
	  'listboxtop',top);
    end
    
   case 'close',
    % check of there is event marked in mark list
    a = findobj('tag','event_list');
    b = str2num(char(get(a,'string')));
    if b(1) ~= 0,
      FMRI.eventlist = b;
    end
    f = findobj('name','Event Editor');
    delete(f);
    
   case 'mark_event',
    % get value in ev_ax saved in event table
    userdata = get(gcf,'userdata');
    val = get(userdata.ev_ax(1),'value');
    a = findobj('tag','event_list');
    b = str2num(char(get(a,'string')));
    ii = find(b==val);
    if isempty(ii),
      b = b';
      if length(b) == 1 & b(1) == 0,
	b = val;
      else
	b = [b val];
	b = sort(b(:));
      end
      set(a,'string',num2str(b));
    else
      fmrlab_messagedlg('fmrlab_eventedit()',...
			'Error:',...
			'Already in the list, skip this one!');
    end
    
   case 'goto_event',
    % access event no from  event list
    a = findobj('tag','event_list');
    b = get(a,'value');
    c = get(a,'string');
    c = str2num(char(c));
    if length(c) == 1 & c(b) == 0,
      return;
    end
    userdata = get(gcf,'userdata');
    for i=1:length(userdata.ev_ax),
      set(userdata.ev_ax(i),'value',c(b));
    end

   case 'unmark_event',
    a = findobj('tag','event_list');
    b = get(a,'value');
    c = str2num(char(get(a,'string')));
    if length(c) == 1 & c(b) == 0,
      str = ['No items in event list'];
      fmrlab_messagedlg('fmrlab_eventedit)_',...
			'Error:',...
			str);
      return;
    end
    userdata = get(gcf,'userdata');
    d = get(userdata.ev_ax(1),'value');
    if c(b) ~= d,
      str = ['Item not match, please first select the event you' ...
	     ' want to delete in the event list!'];
      fmrlab_messagedlg('fmrlab_eventedit()',...
		       'Error:',...
		       str);
      return;
    end
    c(b) = [];
    if isempty(c),
      set(a,'string','0',...
	    'value',1);
    else
      set(a,'string',num2str(c),...
	    'value',1);
    end
    
   case 'unmark_all',
    a = findobj('tag','event_list');
    set(a,'string','0',...
	  'value',1);
    
   case 'export_event',
    % check if there is no marked event in the event list
    a = findobj('tag','event_list');
    b = str2num(char(get(a,'string')));
    if length(b) == 1 & b(1) == 0,
      str = ['No items in event list, please select the event you' ...
	     ' want to export first!'];
      fmrlab_messagedlg('fmrlab_eventedit()',...
			'Warning:',...
			str);
      return;
    end
    iievent = b;
    % check which fields the user wants to export
    userdata = get(gcf,'userdata');
    iifield = [];
    for i=1:length(userdata.ck_ax),
      if get(userdata.ck_ax(i),'value')==1,
	iifield = [iifield i];
      end
    end
    % get all the values,
    a = [];
    b = [];
    exp_data = zeros(length(iifield),length(iievent));
    for i=1:length(iifield),
      a{i} = get(userdata.ev_ax(iifield(i)),'string');
      b{i} = a{i}(iievent);
      if get(userdata.cv_ax(iifield(i)),'value') == 1,
	temp = str2num(char(b{i}));
	str = get(userdata.ca_ax(iifield(i)),'string');
	if ~isempty(str),
	  g = inline(str);
	  temp = g(temp);
	end
      end
      exp_data(i,:) = round(temp(:)');
    end
    % popup file selection window for user to save export data
    [fname,pname]=uiputfile('*.mat','Save Exported Event as');
    fname = [pname fname];
    save(fname,'exp_data');
    
  end
  