% fmrlab_granger_causality()
%   calculating granger causality between the time courses
%   of every possible component pair.
%
% Inputs:
%   data - component time course matrix component by time point (invW' for example)
%   lags - lags applied to calculate granger causality
%
% Outputs: 
%   gc  - granger causality
%   fs  - f-test result
%   b   - beta obtained in regression
%   res - residules for regression
%   rss - sum of square of residules
%
% Author: Jeng-Ren Duann, SCCN/INC/UCSD, 2006-06-30
%

function [gc,fs,b,res,rss]=fmrlab_granger_causality(data,lags)

sz = size(data);
if sz(1) > sz(2),
  disp('time points should be more than component no., please');
  return;
end

% remove mean of the input data matrix
mm =mean(data');
mm = repmat(mm',1,sz(2));
data = data-mm;

% create lag matric for regression
lag_mat = zeros(sz(1),sz(2)-lags,lags);
for ii=1:sz(1),
  for jj=1:lags,
    lag_mat(ii,:,lags-jj+1) = data(ii,jj:sz(2)-lags+jj-1);
  end
end

% computing auto-regression
x = [];
for ii=1:sz(1),
  x =[x squeeze(lag_mat(ii,:,:))];
end
%x = squeeze(x);
for ii=1:sz(1),
  temp = data(ii,:)';
  y = temp(lags+1:end);
  %[bb,bbint,rr]=regress(y,x);
  %b(:,ii) = bb;
  %res(:,ii) = rr;
  b(:,ii) = x\y;
  res(:,ii) = y-x*b(:,ii);
  rss1(ii) = sum(res(:,ii).^2);
end

% compute regression with all other components
for ii=1:sz(1),
  temp = data(ii,:)';
  y = temp(lags+1:end);
  for jj=1:sz(1),
    if jj~=ii,
      x =[];
      for kk=1:sz(1),
        if kk ~= jj
          x = [x squeeze(lag_mat(kk,:,:))];
        end
      end
      %[bb,bbint,rr]=regress(y,x);
      bb = x\y;
      rr = y-x*bb;
      rss0(ii,jj) = sum(rr.^2);
    end
  end
  disp(['comp ' num2str(ii) ' finished...']);
end

% compute F value
gc = ones(sz(1)).*NaN;
fs = zeros(sz(1));
for ii=1:sz(1)-1,
  for jj=ii+1:sz(1),
    fs(ii,jj) = ((rss0(ii,jj)-rss1(ii))/lags)/(rss1(ii)/(sz(2)-3*lags-1));
    gc(ii,jj) = 1-cdf('f',fs(ii,jj),lags,sz(2)-3*lags-1);
    fs(jj,ii) = ((rss0(jj,ii)-rss1(jj))/lags)/(rss1(jj)/(sz(2)-3*lags-1));
    gc(jj,ii) = 1-cdf('f',fs(jj,ii),lags,sz(2)-3*lags-1);
  end
end

for ii=1:sz(1),
  temp = data(ii,lags+1:end);
  rst2 = temp*temp';
  rss(ii) = 1-(rss1(ii)./rst2);
end
