% fmrlab_importevent() - Import events into FMRLAB through ascii file
%
% Usage:
%    fmrlab_importevent(act);
%
% Input:
%    act - actions
%        - 'init': initialize window
%        - 'load':
% Outputs:
%
% Author: Jeng-Ren Duann, SCCN/INC/UCSD & CNL/Salk Inst., 2004
%
% See also: generate_event(),

% --
% Copyright (C) 2002 Jeng-Ren Duann, Salk Institute, duann@salk.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: fmrlab_importevent.m,v $
% Revision 1.1  2004/10/04 13:46:56  duann
% Initial revision
%

function fmrlab_importevent(act)

global FMRI
global FS
global sf
global tw
global axg

if length(FMRI) == 0,
  fmrlab_messagedlg('Component ROAs on fMRI',...
		 'Error:',...
		 ['No current data set exists. Please load a ''.fmr''' ...
		  ' data file first.']);
  return;
end

if nargin<1,
  action = 'init';
end

RGB_mainwin = [1 .984 .895];
RGB_background = [0.860 0.824 0.618];
RGB_button = [0.860 0.824 0.618]; 
RGB_text = [0.333 0.283 0.003];
RGB_input = [0.1 0.5 0.5];

pos_w = 300*sf(1); % window width
pos_h = 200*sf(2); % window height
axg = 5*min(sf); % gap in x- and y-direction
bw = 100*sf(1); % width of button
bh = 20*sf(2); % height of button
tw = 18; % width of title bar

switch(act),
    case 'init',
        f0 = findobj('name','Import Event from ASCII File');
        if ~isempty(f0),
            figure(f0);
        else
            disp('Create all controls...');
            S = get(0,'screensize');
            pos = [(S(3)-pos_w)/2 (S(4)-pos_h)/2 pos_w pos_h];
            f0 = figure( ...
                'name', 'Import Event from ASCII File', ...
                'numbertitle','off',...
                'doublebuffer', 'on', ...
                'color',RGB_mainwin,...
                'menubar','none',...
                'position',pos,...
                'backingstore','off');
            
            % create controls for file name
            pos = [axg pos_h-axg-bh bw bh];
            uicontrol(...
                'parent',f0,...
                'style','text',...
                'position',pos,...
                'fontsize',FS,...
                'fontweight','bold',...
                'string','Event File Name:',...
                'backgroundcolor',RGB_mainwin,...
                'foregroundcolor',RGB_text);
            pos(2) = pos(2)-bh;
            pos(3) = pos(3)*2.9;
            uicontrol(...
                'parent',f0,...
                'style','edit',...
                'position',pos,...
                'fontsize',FS,...
                'fontweight','bold',...
                'horizontalalignment','left',...
                'backgroundcolor',RGB_button,...
                'foregroundcolor',RGB_input,...
                'tag','edit_filename');
            pos(1) = pos(1)+2*bw+axg;
            pos(2) = pos(2)-bh-axg;
            pos(3) = 0.8*bw;
            uicontrol(...
                'parent',f0,...
                'style','pushbutton',...
                'position',pos,...
                'fontsize',FS,...
                'fontweight','bold',...
                'string','Find File',...
                'backgroundcolor',RGB_button,...
                'foregroundcolor',RGB_text,...
                'callback','fmrlab_importevent(''filename'')');
            
            % create controls for field names
            pos(1) = axg;
            pos(2) = pos(2)-bh-axg;
            pos(3) = 2*bw;
            uicontrol(...
                'parent',f0,...
                'style','text',...
                'position',pos,...
                'fontsize',FS,...
                'fontweight','bold',...
                'horizontalalignment','left',...
                'string','Fields Contained in File:',...
                'backgroundcolor',RGB_mainwin,...
                'foregroundcolor',RGB_text);
            pos(2) = pos(2)-bh;
            pos(3) = 2.9*bw;
            uicontrol(...
                'parent',f0,...
                'style','edit',...
                'position',pos,...
                'fontsize',FS,...
                'fontweight','bold',...
                'horizontalalignment','left',...
                'string','''event_type'',''latency''',...
                'backgroundcolor',RGB_button,...
                'foregroundcolor',RGB_input,...
                'tag','edit_fieldnames');
            
            % create controls for time unit
            pos(2) = pos(2)-bh-axg;
            pos(3) = 2*bw;
            uicontrol(...
                'parent',f0,...
                'style','text',...
                'position',pos,...
                'fontsize',FS,...
                'fontweight','bold',...
                'horizontalalignment','left',...
                'string','Time Unit (ms, s, scan):',...
                'backgroundcolor',RGB_mainwin,...
                'foregroundcolor',RGB_text);
            pos(2) = pos(2)-bh;
            pos(3) = 2.9*bw;
            uicontrol(...
                'parent',f0,...
                'style','edit',...
                'position',pos,...
                'fontsize',FS,...
                'fontweight','bold',...
                'horizontalalignment','left',...
                'string','ms',...
                'backgroundcolor',RGB_button,...
                'foregroundcolor',RGB_input,...
                'tag','edit_timeunit');
            
            % create control buttons
            pos(1) = axg + bw;
            pos(2) = pos(2)-2*axg-bh;
            pos(3) = 0.8*bw;
            uicontrol(...
                'parent',f0,...
                'style','pushbutton',...
                'position',pos,...
                'fontsize',FS,...
                'fontweight','bold',...
                'string','OK',...
                'backgroundcolor',RGB_button,...
                'foregroundcolor',RGB_text,...
                'callback','fmrlab_importevent(''load'')');
            pos(1) = 2*(axg + bw);
            uicontrol(...
                'parent',f0,...
                'style','pushbutton',...
                'position',pos,...
                'fontsize',FS,...
                'fontweight','bold',...
                'string','Cancel',...
                'backgroundcolor',RGB_button,...
                'foregroundcolor',RGB_text,...
                'callback','fmrlab_importevent(''cancel'')');
        end
        
    case 'cancel',
        f0 = findobj('name','Import Event from ASCII File');
        if ~isempty(f0)
            delete(f0);
        end
        
    case 'filename',
        [fname,pname] = uigetfile('*.txt');
        if fname ~= 0,
            fname = [pname fname];
            f0 = findobj('name','Import Event from ASCII File');
            if ~isempty(f0),
                a = findobj(f0,'tag','edit_filename');
                set(a,'string',fname);
            end
        end
        
    case 'load',
        f0 = findobj('name','Import Event from ASCII File');
        if ~isempty(f0),
            a = findobj(f0,'tag','edit_filename');
            fname = get(a,'string');
            a = findobj(f0,'tag','edit_fieldnames');
            fidname = get(a,'string')
            a = findobj(f0,'tag','edit_timeunit');
            tunit = get(a,'string');
            
            switch(tunit),
                case 'ms',
                    str = ['importevent('''',[],' num2str(1/FMRI.tr/1000) ',''fields'',{' fidname '},''event'',''' fname ''');']
                case 's',
                    str = ['importevent('''',[],' num2str(1/FMRI.tr) ',''fields'',{' fidname '},''event'',''' fname ''');']
                case 'scan',
                    str = ['importevent('''',[],1,''fields'',{' fidname '},''event'',''' fname ''');']
            end
            FMRI.event = eval(str);
            if FMRI.dummy ~= 0,
                for ii=1:size(FMRI.event,2),
                    FMRI.event(ii).latency = FMRI.event(ii).latency - FMRI.dummy;
                    if FMRI.event(ii).latency < 0,
                        FMRI.event(ii).latency = 0;
                    end
                end
            end
        end
        delete(f0);
end