% fmrlab_label_comps_map() - 
%   select component(s) based on spatial correlation between
%   component ROAs and selected spatial template.
%   The spatial template files were stored in templates/ under
%   FMRLAB main directory (e.g., fusiform.img and .hdr and so on)
%
% Usage: fmrlab_label_comps_map();
%
% Inputs:
%
% Outputs:
%
% Author: Jeng-Ren Duann, CNL/Salk Inst. & SCCN/INC/UCSD, 2007
%
% See also: fmrlab_label_comps_time()
%
% Notes: - 

% Copyright (C) 2007 Jeng-Ren Duann, INC/UCSD, duann@sccn.ucsd.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: fmrlab_normalize.m,v $
%
% Revision 1.1  2007/05/29  duann
% Initial revision
%

function fmrlab_label_comps_map(act)

RGB_mainwin = [1 .984 .895];
RGB_background = [0.860 0.824 0.618];
RGB_button = [0.860 0.824 0.618];
RGB_text = [0.333 0.283 0.3];

if nargin < 1
    act = 'init';
end

window_name = 'Select components using spatial correlations';

switch(act)
case 'init',
  F = findobj('name',window_name);
  if ~isempty(F),
    figure(F);
  else
    S = get(0,'screensize');
    main_win_pos = [(S(3)-640)/2 (S(4)-480)/2 640 480];
    F = figure(...
      'numbertitle','off',...
      'menubar','none',...
      'toolbar','none',...
      'name',window_name,...
      'color',RGB_mainwin,...
      'position',main_win_pos);

    % create label and button for selecting component list
    pos = [10 450 150 25];
    uicontrol(...
      'parent',F,...
      'style','text',...
      'position',pos,...
      'fontsize',14,...
      'fontweight','bold',...
      'string','Component list:',...
      'backgroundcolor',RGB_mainwin,...
      'foregroundcolor',RGB_text,...
      'horizontalalignment','left');
    pos(1) = pos(1) + 160;
    uicontrol(...
      'parent',F,...
      'style','pushbutton',...
      'position',pos,...
      'fontsize',14,...
      'fontweight','bold',...
      'string','Set DIR...',...
      'backgroundcolor',RGB_button,...
      'foregroundcolor',RGB_text,...
      'horizontalalignment','center',...
      'callback','fmrlab_label_comps_map(''sel_dir'')');
    pos(1) = 10;
    pos(2) = pos(2)-30;
    pos(3) = 400;
    uicontrol(...
      'parent',F,...
      'style','edit',...
      'position',pos,...
      'fontsize',12,...
      'backgroundcolor',RGB_mainwin,...
      'foregroundcolor',RGB_text,...
      'horizontalalignment','left',...
      'tag','ed_dir');

    pos(2) = pos(2)-30;
    pos(3) = 150;
    uicontrol(...
      'parent',F,...
      'style','text',...
      'position',pos,...
      'fontsize',14,...
      'fontweight','bold',...
      'string','Template:',...
      'backgroundcolor',RGB_mainwin,...
      'foregroundcolor',RGB_text,...
      'horizontalalignment','left');
    pos(1) = pos(1) + 160;
    uicontrol(...
      'parent',F,...
      'style','pushbutton',...
      'position',pos,...
      'fontsize',14,...
      'fontweight','bold',...
      'string','Select...',...
      'backgroundcolor',RGB_button,...
      'foregroundcolor',RGB_text,...
      'horizontalalignment','center',...
      'callback','fmrlab_label_comps_map(''sel_temp'')');
    pos(1) = 10;
    pos(2) = pos(2)-30;
    pos(3) = 400;
    uicontrol(...
      'parent',F,...
      'style','edit',...
      'position',pos,...
      'fontsize',12,...
      'backgroundcolor',RGB_mainwin,...
      'foregroundcolor',RGB_text,...
      'horizontalalignment','left',...
      'tag','ed_temp');

    pos(1) = 480;
    pos(2) = 450;
    pos(3) = 150;
    uicontrol(...
      'parent',F,...
      'style','pushbutton',...
      'position',pos,...
      'fontsize',14,...
      'fontweight','bold',...
      'string','Compute...',...
      'backgroundcolor',RGB_button,...
      'foregroundcolor',RGB_text,...
      'horizontalalignment','center',...
      'callback','fmrlab_label_comps_map(''compute'')');
    pos(2) = 390;
    uicontrol(...
      'parent',F,...
      'style','pushbutton',...
      'position',pos,...
      'fontsize',14,...
      'fontweight','bold',...
      'string','Exit!',...
      'backgroundcolor',RGB_button,...
      'foregroundcolor',RGB_text,...
      'horizontalalignment','center',...
      'callback','fmrlab_label_comps_map(''close'')');

    pos = [60 40 570 310];
    ax = axes(...
      'parent',F,...
      'unit','pixel',...
      'position',pos,...
      'color',RGB_mainwin,...
      'box','on',...
      'tag','ax_plot',...
      'xtick',[],...
      'ytick',[],...
      'xticklabel',[],...
      'yticklabel',[]);

    % save necessary variables in userdata of main win
    userdata.ax = ax;
    userdata.window_name = window_name;
    set(F,'userdata',userdata);
  end

case 'close',
  close(gcf);

case 'sel_dir',
  pname = uigetdir;
  if pname ~= 0,
    a = findobj('tag','ed_dir');
    set(a,'string',pname);
  end

case 'sel_temp',
  pname = which('fmrlab');
  pname = pname(1:length(pname)-8);
  pname = [pname 'templates/'];
  fname = uigetfile('*.img','Select Template',pname);
  if fname ~= 0,
    a = findobj('tag','ed_temp');
    set(a,'string',fname);
  end
  
case 'compute',
  % check if the necessary files are there
  a = findobj('tag','ed_dir');
  b = get(a,'string');
  if isempty(b),
    fmrlab_messagedlg('No component dir specified',...
      'Error',...
      'Please specify component dir first',...
      {'OK'});
    return;
  end
  comp_dir = b;

  a = findobj('tag','ed_temp');
  b = get(a,'string');
  if isempty(b),
    fmrlab_messagedlg('No template specified',...
      'Error',...
      'Please specify template first',...
      {'OK'});
    return;
  end
  temp = b;
  
  % list all nroa*.img into file filelist under the comp_dir
  system(['ls ' comp_dir '/nroa*.img > ' comp_dir '/filelist']);
  % load template first
  pname = which('fmrlab');
  pname = pname(1:length(pname)-8);
  fname = [pname 'templates/' temp];
  fp = fopen(fname,'rb','ieee-le');
  temp_img = fread(fp,'uint8');
  fclose(fp);
  if max(temp_img) ~= 1,
    fp = fopen(fnema,'rb','ieee-be');
    temp_img = fread(fp,'uint8');
    fclose(fp);
  end

  % open normalizsed roa maps
  fname = [comp_dir '/filelist'];
  fp = fopen(fname,'r');
  comp_no = [];
  comp_cc = [];
  set(gcf,'pointer','watch');
  while ~feof(fp),
    a = fgets(fp);
    a = a(1:length(a)-1);
    % resolve component no.
    b = findstr(a,'nroa_');
    comp_no = [comp_no str2num(a(b+6:b+9))];
    fp1 = fopen(a,'rb','ieee-le');
    roa_img = fread(fp1,'float');
    fclose(fp1);
    roa_img = (roa_img-mean(roa_img))/std(roa_img);
    ii = find(abs(roa_img) >= 2); % ROAs
    bi_roa_img = zeros(size(roa_img));
    bi_roa_img(ii) = 1;
    and_roa_img = and(bi_roa_img,temp_img);
    ii = find(and_roa_img==1);
    jj = find(temp_img==1);
    comp_cc = [comp_cc length(ii)/length(jj)];
  end
  fclose(fp);
  set(gcf,'pointer','arrow');
  
  if isempty(comp_cc),
    fmrlab_messagedlg('No ROA found',...
	  'Warning',...
	  'No normalized ROA maps found, please check the specified dir',...
	  {'OK'});
	return;
  else
    userdata = get(gcf,'userdata');
    axes(userdata.ax);
    plot(comp_no,comp_cc,'ro-');
    for i=1:length(comp_no),
      tx=text(comp_no(i)+0.5,comp_cc(i),num2str(comp_no(i)));
      set(tx,'fontsize',9);
    end
    a = get(gca,'xlabel');
    set(a,'string','Comp. No.','fontsize',14,'fontweight','bold');
    a = get(gca,'ylabel');
    set(a,'string','Overlap Ratio','fontsize',14,'fontweight','bold');

    % save derived variable
    userdata.comp_no = comp_no;
    userdata.comp_cc = comp_cc;
    userdata.gca = gca;
    set(gcf,'userdata',userdata);
  end
end



