% fmrlab_overlapping() - calculating the overlapping between the component maps
%                        with respect to the given ROA threshold.
%                        If there is no overlapping between component maps, the 
%                        sum of proportion of component maps should be <= 1.0.
%                        If more overlapping, the sum of proportions of component 
%                        maps should be greater than 1.0.
%
% Author: Jeng-Ren Duann, SCCN/INC/UCSD, 2006-06-22

function overlap_ratio = fmrlab_overlapping(z_thre)

global FMRI

if nargin < 1,
  z_thre = 2.0;
end

if isempty(FMRI.icaweight),
  disp('Please launch this function after ICA decomposition...');
  return;
end

W = FMRI.icaweight*FMRI.icasphere;
invW = pinv(W);
u = W * FMRI.data;

overlap_ratio = 0;
for i=1:size(FMRI.icaweight,1),
  temp = u(i,:);
  temp = (temp-mean(temp))/std(temp);
  ii = find(abs(temp)>=z_thre);
  overlap_ratio = overlap_ratio + length(ii)/length(FMRI.idx);
end
