% fmrlab_rmeyes() - remove portion of images from fMRI time series data
%                   from ICA training.
% 
%                   2005-12-15 eye activities in fMRI time series data
%                              is a big distractors for ICA decompositions.
%                              They contain high dimensional data, which need
%                              multiple components (can be up to the full
%                              rank of the data) to account for their time
%                              courses.
                              
function fmrlab_rmeyes

global FMRI

% restore FMRI data baseline
if isfield(FMRI,'voxmm'),
  if FMRI.voxmm ~= 0,
    if length(FMRI.runidx) == 1,
      temp = repmat(FMRI.voxmm,size(FMRI.data,1),1);
    else
      temp1 = [FMRI.runidx size(FMRI.data,1)+1];
      for ii=1:length(FMRI.runidx),
        temp(temp1(ii):temp1(ii+1)-1,:) = repmat(FMRI.voxmm(ii,:),temp1(ii+1)-temp1(ii),1);
      end
    end
    FMRI.data = FMRI.data + temp;
    FMRI.runidx = [];
    FMRI.voxmm = 0;
  end
end

temp = FMRI.data(1,:);
temp1 = zeros(1,FMRI.dime_x*FMRI.dime_y*FMRI.dime_z);
for i=1:length(FMRI.idx)
  temp1(FMRI.idx(i)) = temp(i);
end

temp1 = reshape(temp1,FMRI.dime_x,FMRI.dime_y,FMRI.dime_z);
fig = figure;
disp_col = ceil(sqrt(FMRI.dime_z));
disp_row = ceil(FMRI.dime_z/disp_col);
fig_parents = [];
for i=1:FMRI.dime_z,
  h = tightsubplot(disp_row,disp_col,i);
  fig_parents = [fig_parents h];
  imagesc(temp1(:,:,i)');
  axis off
  axis image
end
colormap(gray);

% select eye portion to remove
rm_coor = [];
while(1),
  waitforbuttonpress
  a = get(gco);
  if isfield(a,'CData'),
    pp = get(gco,'parent');
    ii = find(fig_parents==pp);
    img_data = get(gco,'CData');
    fig2 = figure;
    imagesc(img_data);
    axis image;
    a = ginput(2);
    a(:,1) = floor(a(:,1));
    a(:,2) = ceil(a(:,2));
    close(fig2);
    if a(1,1) > a(2,1),
      sw = a(1,1);
      a(1,1) = a(2,1);
      a(2,1) = sw;
    end
    if a(1,2) > a(2,2),
      sw = a(1,2);
      a(1,2) = a(2,2);
      a(2,2) = sw;
    end
    for i=a(1,1):a(2,1),
      for j=a(1,2):a(2,2),
        rm_coor = [rm_coor (ii-1)*FMRI.dime_x*FMRI.dime_y+(j-1)*FMRI.dime_x+i];
      end
    end
  else
    disp('End selection ...');
    break;
  end
end

% remove eyes
temp2 = temp1(:)';
temp2(rm_coor) = 0;
temp2 = reshape(temp2,FMRI.dime_x,FMRI.dime_y,FMRI.dime_z);
figure(fig)
disp_col = ceil(sqrt(FMRI.dime_z));
disp_row = ceil(FMRI.dime_z/disp_col);
fig_parents = [];
for i=1:FMRI.dime_z,
  subplot(disp_row,disp_col,i);
  imagesc(temp2(:,:,i)');
end
colormap(gray);

% apply to FMRI.data
temp = zeros(size(FMRI.data,1),FMRI.dime_x*FMRI.dime_y*FMRI.dime_z);
for i=1:length(FMRI.idx),
  temp(:,FMRI.idx(i)) = FMRI.data(:,i);
end
for i=1:length(rm_coor),
  ii = find(FMRI.idx == rm_coor(i));
  if ~isempty(ii),
    FMRI.idx(ii) = [];
  end
end
FMRI.data = temp(:,FMRI.idx);
show_parameters;

% check if the new data set is correct
temp = FMRI.data(1,:);
temp1 = zeros(1,FMRI.dime_x*FMRI.dime_y*FMRI.dime_z);
for i=1:length(FMRI.idx)
  temp1(FMRI.idx(i)) = temp(i);
end
temp1 = reshape(temp1,FMRI.dime_x,FMRI.dime_y,FMRI.dime_z);
figure(fig);
disp_col = ceil(sqrt(FMRI.dime_z));
disp_row = ceil(FMRI.dime_z/disp_col);
fig_parents = [];
for i=1:FMRI.dime_z,
  subplot(disp_row,disp_col,i);
  imagesc(temp1(:,:,i)');
end

disp('Press any key ...');
pause
close(fig);
