% fmrlab_roi_timecourse() - calculating the time course of the ROI
%     picked by users by clicking the voxels of an ROA map in
%     component browser.
%
% Usage:
%   >> fmrlab_roi_timecourse(action)
%
% Inputs:
%   action - 'init': initialize the popup window
%
% Outputs:
%
% Author: Jeng-Ren Duann, CNL/Salk Inst. & SCCN/INC/UCSD, 2002
%
% See also: map_on_fmri()
%
% Notes: - 
 
% --
% Copyright (C) 2004, Jeng-Ren Duann, SCCN/INC/UCSD and CNL/Salk Inst.
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of
% the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

% $Log: fmrlab_roi_timecourse.m,v $

function fmrlab_roi_timecourse(action)

  global FMRI
  global FS
  
  if length(FMRI) == 0,
    fmrlab_messagedlg('Component ROAs on fMRI',...
		      'Error:',...
		      ['No current data set exists. Please load a ''.fmr''' ...
		       ' data file first.']);
    return;
  end
  
  temp = findstr(FMRI.processed,'ica_trained');
  if isempty(temp),
    fmrlab_messagedlg('map_on_fmri3()',...
		      'Error:',...
		      'No ICA results, please run ''Process >> Run ICA''');
    return;
  end

  if nargin<1,
    action = 'init';
  end

  RGB_mainwin = [1 .984 .895];
  RGB_background = [0.860 0.824 0.618];
  RGB_button = [0.860 0.824 0.618]; 
  RGB_text = [0.333 0.283 0.003];

  switch(action),
   case 'init',
    f0 = findobj('name','VOI Time Course');
    if ~isempty(f0),
      figure(f0);
    else
      disp('Create all controls...');
      S = get(0,'screensize');
      pos = [S(3)-510 S(4)-450 500 400];
      f0 = figure( ...
	  'name', 'VOI Time Course', ...
	  'numbertitle','off',...
	  'doublebuffer', 'on', ...
	  'color',RGB_mainwin,...
	  'menubar','none',...
	  'position',pos,...
	  'backingstore','off');
      
      % create axes for time course plot
      pos = [5 5 490 200];
      ax = axes(...
	  'parent',f0,...
	  'units','pixels',...
	  'position',pos,...
	  'color',RGB_mainwin,...
	  'box','on',...
	  'tag','tc_plot',...
	  'xtick',[],...
	  'xticklabel',[],...
	  'ytick',[],...
	  'yticklabel',[]);
      
      % create combobox for time course type selection
      listStr = {'The single voxel clicked',...
		 '3x3x3 VOI averaged',...
		 '3x3x3 VOI max. z-value',...
		 '5x5x5 VOI averaged',...
		 '5x5x5 VOI max. z-value'};
      pos = [5 375 175 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','Time course source:',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','left',...
	  'fontweight','bold');
      pos = [180 375 300 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','popupmenu',...
	  'string',listStr,...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'fontweight','bold',...
	  'tag','select_comp',...
	  'value',1);
      
      % create edit for showing coordinate selected
      pos = [5 350 120 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','Coordinates:',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','left',...
	  'fontweight','bold');
      pos = [5 325 90 25];
      
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','blue -',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','right',...
	  'fontweight','bold');
      pos = [100 325 150 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','left',...
	  'fontweight','bold',...
	  'tag','blue_coor');
      
      pos = [5 300 90 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','cyan -',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','right',...
	  'fontweight','bold');
      pos = [100 300 150 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','left',...
	  'fontweight','bold',...
	  'tag','cyan_coor');
      
      pos = [5 275 90 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','green -',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','right',...
	  'fontweight','bold');
      pos = [100 275 150 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','left',...
	  'fontweight','bold',...
	  'tag','green_coor');
      
      pos = [5 250 90 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','black -',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','right',...
	  'fontweight','bold');
      pos = [100 250 150 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','left',...
	  'fontweight','bold',...
	  'tag','black_coor');
      
      pos = [255 325 90 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','megenta -',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','right',...
	  'fontweight','bold');
      pos = [350 325 150 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','left',...
	  'fontweight','bold',...
	  'tag','megenta_coor');
      
      pos = [255 300 90 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','red -',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','right',...
	  'fontweight','bold');
      pos = [350 300 150 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','left',...
	  'fontweight','bold',...
	  'tag','red_coor');
      
      pos = [255 275 90 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','yellow -',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','right',...
	  'fontweight','bold');
      pos = [350 275 150 25];
      uicontrol(...
	  'parent',f0,...
	  'position',pos,...
	  'style','text',...
	  'string','',...
	  'backgroundcolor',RGB_mainwin,...
	  'foregroundcolor',RGB_text,...
	  'fontsize',14,...
	  'horizontalalign','left',...
	  'fontweight','bold',...
	  'tag','yellow_coor');
      
    end
    
  end
  