% fmrlab_sn() - manual spatial normalization with graphic user interface for user
%                to adjust manually (acording to eye-ball inspection)
%
% Usage: 
%    >> fmrlab_sn(act);
%
% Input:
%    act = callback of functional fmrlab_sn(), options:
%          'init' - make the main control panel
%
% Output:
%
% Author: Jeng-Ren Duann, SCCN/INC/UCSD & INC/Salk Inst., 2004-05
%
% See also:
%
% Note:
%

function fmrlab_sn(act)

if nargin < 1,
    act = 'init';
end

RGB_mainwin = [1 .984 .895];
RGB_background = [0.860 0.824 0.618];
RGB_button = [0.860 0.824 0.618];
RGB_text = [0.333 0.283 0.003];

global adju_dime
global adju_img
global current_adju_dime
global temp_dime
global temp_img
global current_temp_dime
global ax

switch (act),
case 'init',
    f1 = findobj('name','Manual Spatial Normalization');
    if isempty(f1),
        pos = [5 40 1024-10 768-70];
        f1 = figure(...
            'name','Manual Spatial Normalization',...
            'numbertitle','off',...
            'toolbar','none',...
            'menubar','none',...
            'position',pos,...
            'color',RGB_background);
        % create text for "Adjusted:" and "Template:"
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','text',...
            'position',[5 pos(4)-25 250 20],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'string','Adjusted:');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','text',...
            'position',[15+250*2 pos(4)-25 250 20],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'string','Template:');
        % create aces for adjust image
        ax(1) = axes(...
            'Parent',f1, ...
            'units','pixels',...
            'position',[5 pos(4)-25-255 250 250],...
            'Color',RGB_mainwin, ...
            'box','on',...
            'Tag','image_ax',...
            'xtick',[],...
            'xticklabel',[],...
            'ytick',[],...
            'yticklabel',[]);
        ax(2) = axes(...
            'Parent',f1, ...
            'units','pixels',...
            'position',[5+255 pos(4)-25-255 250 250],...
            'Color',RGB_mainwin, ...
            'box','on',...
            'Tag','image_ax',...
            'xtick',[],...
            'xticklabel',[],...
            'ytick',[],...
            'yticklabel',[]);
        ax(3) = axes(...
            'Parent',f1, ...
            'units','pixels',...
            'position',[5 pos(4)-25-255*2 250 250],...
            'Color',RGB_mainwin, ...
            'box','on',...
            'Tag','image_ax',...
            'xtick',[],...
            'xticklabel',[],...
            'ytick',[],...
            'yticklabel',[]);
        % create button for loading adjusted image
        uicontrol(...
            'Parent',f1, ...
            'style','pushbutton',...
            'BackgroundColor',RGB_button, ...
            'FontSize',14, ...
            'ForegroundColor',RGB_text, ...
            'Position',[5+255 pos(4)-25-255-30 250 25], ...
            'String','Load Adjusted Image', ...
            'callback','fmrlab_sn(''load_adju'')');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','text',...
            'position',[5+255 pos(4)-25-255-90 250 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'string','Select slice:');
        % select slice x
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','text',...
            'position',[15+255 pos(4)-25-255-120 20 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'string','x:');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','edit',...
            'position',[15+255+25 pos(4)-25-255-120 80 25],...
            'fontsize',12,...
            'horizontalalign','center',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''adju_refresh_edit'')',...
            'tag','edit_adju_x');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','slider',...
            'position',[15+255+110 pos(4)-25-255-120 120 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''adju_refresh_slider'')',...
            'tag','slider_adju_x');
        % select slice y
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','text',...
            'position',[15+255 pos(4)-25-255-150 20 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'string','y:');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','edit',...
            'position',[15+255+25 pos(4)-25-255-150 80 25],...
            'fontsize',12,...
            'horizontalalign','center',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''adju_refresh_edit'')',...
            'tag','edit_adju_y');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','slider',...
            'position',[15+255+110 pos(4)-25-255-150 120 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''adju_refresh_slider'')',...
            'tag','slider_adju_y');
        % select slice z
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','text',...
            'position',[15+255 pos(4)-25-255-180 20 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'string','z:');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','edit',...
            'position',[15+255+25 pos(4)-25-255-180 80 25],...
            'fontsize',12,...
            'horizontalalign','center',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''adju_refresh_edit'')',...
            'tag','edit_adju_z');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','slider',...
            'position',[15+255+110 pos(4)-25-255-180 120 25],...
            'fontsize',14,...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''adju_refresh_slider'')',...
            'tag','slider_adju_z');
        % create axes for template image
        ax(4) = axes(...
            'Parent',f1, ...
            'units','pixels',...
            'position',[5+255*2 pos(4)-25-255 250 250],...
            'Color',RGB_mainwin, ...
            'box','on',...
            'Tag','image_ax',...
            'xtick',[],...
            'xticklabel',[],...
            'ytick',[],...
            'yticklabel',[]);
        ax(5) = axes(...
            'Parent',f1, ...
            'units','pixels',...
            'position',[5+255*3 pos(4)-25-255 250 250],...
            'Color',RGB_mainwin, ...
            'box','on',...
            'Tag','image_ax',...
            'xtick',[],...
            'xticklabel',[],...
            'ytick',[],...
            'yticklabel',[]);
        ax(6) = axes(...
            'Parent',f1, ...
            'units','pixels',...
            'position',[5+255*2 pos(4)-25-255*2 250 250],...
            'Color',RGB_mainwin, ...
            'box','on',...
            'Tag','image_ax',...
            'xtick',[],...
            'xticklabel',[],...
            'ytick',[],...
            'yticklabel',[]);
        % create button for loading adjusted image
        uicontrol(...
            'Parent',f1, ...
            'style','pushbutton',...
            'BackgroundColor',RGB_button, ...
            'FontSize',14, ...
            'ForegroundColor',RGB_text, ...
            'Position',[5+255*3 pos(4)-25-255-30 250 25], ...
            'String','Load Template Image', ...
            'callback','fmrlab_sn(''load_temp'')');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','text',...
            'position',[5+255*3 pos(4)-25-255-90 250 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'string','Select slice:');
        % select slice x
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','text',...
            'position',[15+255*3 pos(4)-25-255-120 20 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'string','x:');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','edit',...
            'position',[15+255*3+25 pos(4)-25-255-120 80 25],...
            'fontsize',12,...
            'horizontalalign','center',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''temp_refresh_edit'')',...
            'tag','edit_temp_x');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','slider',...
            'position',[15+255*3+110 pos(4)-25-255-120 120 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''temp_refresh_slider'')',...
            'tag','slider_temp_x');
        % select slice y
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','text',...
            'position',[15+255*3 pos(4)-25-255-150 20 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'string','y:');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','edit',...
            'position',[15+255*3+25 pos(4)-25-255-150 80 25],...
            'fontsize',12,...
            'horizontalalign','center',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''temp_refresh_edit'')',...
            'tag','edit_temp_y');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','slider',...
            'position',[15+255*3+110 pos(4)-25-255-150 120 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''temp_refresh_slider'')',...
            'tag','slider_temp_y');
        % select slice z
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','text',...
            'position',[15+255*3 pos(4)-25-255-180 20 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'string','z:');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','edit',...
            'position',[15+255*3+25 pos(4)-25-255-180 80 25],...
            'fontsize',12,...
            'horizontalalign','center',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''temp_refresh_edit'')',...
            'tag','edit_temp_z');
        uicontrol(...
            'parent',f1,...
            'units','pixels',...
            'style','slider',...
            'position',[15+255*3+110 pos(4)-25-255-180 120 25],...
            'fontsize',14,...
            'horizontalalign','left',...
            'backgroundcolor',RGB_background,...
            'foregroundcolor',RGB_text,...
            'callback','fmrlab_sn(''temp_refresh_slider'')',...
            'tag','slider_temp_z');
    else
        figure(f1);
    end
    
case 'load_adju',
    [fname, pname] = uigetfile('*.hdr','Analyze header file (*.hdr)');
    if fname ~= 0,
        ii = findstr(fname,'hdr');
        img_name = [fname(1:ii-1) 'img'];
        % get the header information
        hdr = read_analyze_hdr([pname fname]);
        adju_dime = hdr.dim(2:4);
        % set the slice selection controls
        %     slice x
        current_adju_dime(1) = ceil(adju_dime(1)/2);
        a = findobj('tag','slider_adju_x');
        set(a,'max',adju_dime(1),...
            'min',1,...
            'value',current_adju_dime(1),...
            'sliderstep',[1/adju_dime(1) 10/adju_dime(1)]);
        a = findobj('tag','edit_adju_x');
        set(a,'string',num2str(current_adju_dime(1)));
        %     slice y
        current_adju_dime(2) = ceil(adju_dime(2)/2);
        a = findobj('tag','slider_adju_y');
        set(a,'max',adju_dime(2),...
            'min',1,...
            'value',current_adju_dime(2),...
            'sliderstep',[1/adju_dime(2) 10/adju_dime(2)]);
        a = findobj('tag','edit_adju_y');
        set(a,'string',num2str(current_adju_dime(2)));
        %     slice z
        current_adju_dime(3) = ceil(adju_dime(3)/2);
        a = findobj('tag','slider_adju_z');
        set(a,'max',adju_dime(3),...
            'min',1,...
            'value',current_adju_dime(3),...
            'sliderstep',[1/adju_dime(3) 10/adju_dime(3)]);
        a = findobj('tag','edit_adju_z');
        set(a,'string',num2str(current_adju_dime(3)));
        
        % display image
        %   read image
        fp = fopen([pname img_name], 'rb', hdr.byte_order);
        switch (hdr.datatype),
        case 2,
            adju_img = fread(fp,'uint8');
        case 4,
            adju_img = fread(fp,'uint16');
        case 8,
            adju_img = fread(fp,'float');
        end
        fclose(fp);
        adju_img = reshape(adju_img, adju_dime(1), adju_dime(2), adju_dime(3));
        display_image_3d(adju_img, adju_dime, current_adju_dime, ax(1:3));
        
    end
    
case 'load_temp',
    [fname, pname] = uigetfile('*.hdr','Analyze header file (*.hdr)');
    if fname ~= 0,
        ii = findstr(fname,'hdr');
        img_name = [fname(1:ii-1) 'img'];
        % get the header information
        hdr = read_analyze_hdr([pname fname]);
        temp_dime = hdr.dim(2:4);
        % set the slice selection controls
        %     slice x
        current_temp_dime(1) = ceil(temp_dime(1)/2);
        a = findobj('tag','slider_temp_x');
        set(a,'max',temp_dime(1),...
            'min',1,...
            'value',current_temp_dime(1),...
            'sliderstep',[1/temp_dime(1) 10/temp_dime(1)]);
        a = findobj('tag','edit_temp_x');
        set(a,'string',num2str(current_temp_dime(1)));
        %     slice y
        current_temp_dime(2) = ceil(temp_dime(2)/2);
        a = findobj('tag','slider_temp_y');
        set(a,'max',temp_dime(2),...
            'min',1,...
            'value',current_temp_dime(2),...
            'sliderstep',[1/temp_dime(2) 10/temp_dime(2)]);
        a = findobj('tag','edit_temp_y');
        set(a,'string',num2str(current_temp_dime(2)));
        %     slice z
        current_temp_dime(3) = ceil(temp_dime(3)/2);
        a = findobj('tag','slider_temp_z');
        set(a,'max',temp_dime(3),...
            'min',1,...
            'value',current_temp_dime(3),...
            'sliderstep',[1/temp_dime(3) 10/temp_dime(3)]);
        a = findobj('tag','edit_temp_z');
        set(a,'string',num2str(current_temp_dime(3)));

        % display image
        %   read image
        fp = fopen([pname img_name], 'rb', hdr.byte_order);
        switch (hdr.datatype),
        case 2,
            temp_img = fread(fp,'uint8');
        case 4,
            temp_img = fread(fp,'uint16');
        case 8,
            temp_img = fread(fp,'float');
        end
        fclose(fp);
        temp_img = reshape(temp_img, temp_dime(1), temp_dime(2), temp_dime(3));
        display_image_3d(temp_img, temp_dime, current_temp_dime, ax(4:6));
    end
    
case 'adju_refresh_slider',
    a = findobj('tag','slider_adju_x');
    b = get(a,'value');
    b = round(b);
    set(a,'value',b);
    a = findobj('tag','edit_adju_x');
    set(a,'string',num2str(b));
    current_adju_dime(1) = b;
    
    a = findobj('tag','slider_adju_y');
    b = get(a,'value');
    b = round(b);
    set(a,'value',b);
    a = findobj('tag','edit_adju_y');
    set(a,'string',num2str(b));
    current_adju_dime(2) = b;
    
    a = findobj('tag','slider_adju_z');
    b = get(a,'value');
    b = round(b);
    set(a,'value',b);
    a = findobj('tag','edit_adju_z');
    set(a,'string',num2str(b));
    current_adju_dime(3) = b;
    
    display_image_3d(adju_img, adju_dime, current_adju_dime, ax(1:3));
    
case 'adju_refresh_edit',
    a = findobj('tag','edit_adju_x');
    b = str2num(get(a,'string'));
    a = findobj('tag','slider_adju_x');
    set(a,'value',b);
    current_adju_dime(1) = b;
    
    a = findobj('tag','edit_adju_y');
    b = str2num(get(a,'string'));
    a = findobj('tag','slider_adju_y');
    set(a,'value',b);
    current_adju_dime(2) = b;
    
    a = findobj('tag','edit_adju_z');
    b = str2num(get(a,'string'));
    a = findobj('tag','slider_adju_z');
    set(a,'value',b);
    current_adju_dime(3) = b;
    
    display_image_3d(adju_img, adju_dime, current_adju_dime, ax(1:3));
    
case 'temp_refresh_slider',
    a = findobj('tag','slider_temp_x');
    b = get(a,'value');
    b = round(b);
    set(a,'value',b);
    a = findobj('tag','edit_temp_x');
    set(a,'string',num2str(b));
    current_temp_dime(1) = b;
    
    a = findobj('tag','slider_temp_y');
    b = get(a,'value');
    b = round(b);
    set(a,'value',b);
    a = findobj('tag','edit_temp_y');
    set(a,'string',num2str(b));
    current_temp_dime(2) = b;
    
    a = findobj('tag','slider_temp_z');
    b = get(a,'value');
    b = round(b);
    set(a,'value',b);
    a = findobj('tag','edit_temp_z');
    set(a,'string',num2str(b));
    current_temp_dime(3) = b;
    
    display_image_3d(temp_img, temp_dime, current_temp_dime, ax(4:6));
    
    
case 'temp_refresh_edit',
    a = findobj('tag','edit_temp_x');
    b = str2num(get(a,'string'));
    a = findobj('tag','slider_temp_x');
    set(a,'value',b);
    current_temp_dime(1) = b;
    
    a = findobj('tag','edit_temp_y');
    b = str2num(get(a,'string'));
    a = findobj('tag','slider_temp_y');
    set(a,'value',b);
    current_temp_dime(2) = b;
    
    a = findobj('tag','edit_temp_z');
    b = str2num(get(a,'string'));
    a = findobj('tag','slider_temp_z');
    set(a,'value',b);
    current_temp_dime(3) = b;
    
    display_image_3d(temp_img, temp_dime, current_temp_dime, ax(4:6));
    
    
end


function display_image_3d(img, dime, disp_dime, disp_ax)

im = reshape(img(:,disp_dime(2),:), dime(1), dime(3));
axes(disp_ax(1));
imagesc(fliplr(im)'); colormap(gray); axis off; 
ln = line([disp_dime(1) disp_dime(1)], [1 dime(3)]);
set(ln,'color','r','linewidth',2);
ln = line([1 dime(1)], [dime(3)-disp_dime(3) dime(3)-disp_dime(3)]);
set(ln,'color','r','linewidth',2);

im = reshape(img(disp_dime(1),:,:), dime(2), dime(3));
axes(disp_ax(2));
imagesc(fliplr(im)'); colormap(gray); axis off;
ln = line([disp_dime(2) disp_dime(2)], [1 dime(3)]);
set(ln,'color','r','linewidth',2);
ln = line([1 dime(2)], [dime(3)-disp_dime(3) dime(3)-disp_dime(3)]);
set(ln,'color','r','linewidth',2);

im = img(:,:,disp_dime(3));
axes(disp_ax(3));
imagesc(fliplr(im)'); colormap(gray); axis off;
ln = line([disp_dime(1) disp_dime(1)], [1 dime(2)]);
set(ln,'color','r','linewidth',2);
ln = line([1 dime(1)], [dime(2)-disp_dime(2) dime(2)-disp_dime(2)]);
set(ln,'color','r','linewidth',2);
