% pick_comp_masking() - select components by comparing to the pre-
%           defined masking image. The masking image can be obtained
%           with the wfu_pickatlas toolbox
%
% Usage: [comp_list, orm] = pick_comp_masking(2.0, 10);
%
% Inputs: 
%   z_thre - threshold of z-value to select ROA (default = 2.0)
%   spatial_extent - minimum voxel number should be contained in the 
%                    ROI (default = 10)
%
% Output:
%   comp_list - ordered component list according to ORM
%   orm - overlap ratio measure (ORM)
%
% Author: Jeng-Ren Duann, PhD, SCCN/INC/UCSD 2005-05-12
%
% Acknowledgement: Some SPM codes are used to read analyze
%                  format images
%

function [comp_list,orm] = pick_comp_masking(z_thre, spatial_extent)

if nargin < 1,
  z_thre = 2.0;
end

if nargin < 2
  spatial_extent = 10;
end

a = spm_get(1,'*mask*.img','Select masking image');
b = spm_get([],'wroa*.img','Select component ROAs');

v1 = spm_read_vols(spm_vol(a));
v2 = spm_read_vols(spm_vol(b));
ii = find(isnan(v2));
v2(ii) = 0;
orm = [];
for i=1:size(v2,4),
  temp = v2(:,:,:,i);
  ii = find(abs(temp)<z_thre);
  temp(ii) = 0;
  temp2 = and(v1,temp);
  ii = find(temp2 ~= 0);
  jj = find(v1 ~= 0);
  orm = [orm length(ii)/length(jj)];
end
[orm,j] = sort(orm);
orm = fliplr(orm);
comp_list = fliplr(j);
